==> evernode-1.0.1.tar.gz: evernode-1.0.1/evernode/models/base_model.py <==
""" sets base db model for applciation """
from flask import current_app
from datetime import datetime
from sqlalchemy import Column, Integer, DateTime
from .database_model import DatabaseModel
from .json_model import JsonModel


class BaseModel(DatabaseModel, JsonModel):
    """ adds usefull custom attributes for applciation use """

    __abstract__ = True
    id = Column(Integer, primary_key=True)
    updated_at = Column(DateTime)
    created_at = Column(DateTime)

    def __init__(self):
        DatabaseModel.__init__(self)

    def exists(self):
        """ checks if item already exists in database """
        self_object = self.query.filter_by(id=self.id).first()
        if self_object is None:
            return False
        return True

    def updated(self):
        """ update updated_at timestamp """
        self.updated_at = datetime.utcnow()
        self.save()

    def delete(self):
        """ easy delete for db models """
        try:
            if self.exists() is False:
                return None
            self.db.session.delete(self)
            self.db.session.commit()
        except (Exception, BaseException) as error:
            # fail silently
            return None

    def save(self):
        """ easy save(insert or update) for db models """
        try:
            if self.exists() is False:
                self.db.session.add(self)
            # self.db.session.merge(self)
            self.db.session.commit()
        except (Exception, BaseException) as error:
            if current_app.config['DEBUG']:
                print(error)
            # fail silently
            return None

==> evernode-1.1.3.tar.gz: evernode-1.1.3/evernode/models/base_model.py <==
""" sets base db model for applciation """
from flask import current_app
from datetime import datetime
from sqlalchemy import Column, Integer, DateTime, text, TIMESTAMP
from .database_model import DatabaseModel
from .json_model import JsonModel


class BaseModel(DatabaseModel, JsonModel):
    """ Adds usefull custom attributes for applciation use """

    __abstract__ = True
    id = Column(Integer, primary_key=True)
    updated_at = Column(
        DateTime,
        server_default=text('CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP'))
    created_at = Column(TIMESTAMP, server_default=text('CURRENT_TIMESTAMP'))

    def __init__(self):
        DatabaseModel.__init__(self)

    @classmethod
    def where_id(cls, id):
        """ Get db model by id """
        return cls.query.filter_by(id=id).first()

    def exists(self):
        """ Checks if item already exists in database """
        self_object = self.query.filter_by(id=self.id).first()
        if self_object is None:
            return False
        return True

    def updated(self):
        """ Update updated_at timestamp """
        self.updated_at = datetime.utcnow()
        self.save()

    def delete(self):
        """ Easy delete for db models """
        try:
            if self.exists() is False:
                return None
            self.db.session.delete(self)
            self.db.session.commit()
        except (Exception, BaseException) as error:
            # fail silently
            return None

    def save(self):
        """ Easy save(insert or update) for db models """
        try:
            if self.exists() is False:
                self.db.session.add(self)
            # self.db.session.merge(self)
            self.db.session.commit()
        except (Exception, BaseException) as error:
            if current_app.config['DEBUG']:
                raise error
            return None
